@@ -26,6 +26,7 @@ from .utils import get_tree_model, get_tree_item_model, import_app_sitetree_modu
 from .settings import (
     ALIAS_TRUNK, ALIAS_THIS_CHILDREN, ALIAS_THIS_SIBLINGS, ALIAS_THIS_PARENT_SIBLINGS, ALIAS_THIS_ANCESTOR_CHILDREN,
     UNRESOLVED_ITEM_MARKER, RAISE_ITEMS_ERRORS_ON_DEBUG, CACHE_TIMEOUT)
+from .exceptions import SiteTreeError
 
 
 if VERSION >= (1, 9, 0):
@@ -53,6 +54,7 @@ _SITETREE = None
 
 _THREAD_LOCAL = local()
 _THREAD_LANG = 'sitetree_lang'
+_THREAD_CACHE = 'sitetree_cache'
 
 
 def get_sitetree():
@@ -284,7 +286,7 @@ class Cache(object):
         Could be used to show up tree changes made in a different process.
 
         """
-        cache.get('sitetrees_reset', True)
+        cache.set('sitetrees_reset', True)
 
     def init(self):
         """Initializes local cache from Django cache."""
@@ -292,10 +294,15 @@ class Cache(object):
         # Drop cache flag set by .reset() method.
         cache.get('sitetrees_reset') and self.empty()
 
-        cache_ = cache.get('sitetrees')
+        cache_ = getattr(_THREAD_LOCAL, _THREAD_CACHE, None)
         if cache_ is None:
-            # Init cache dictionary with predefined entries.
-            cache_ = {'sitetrees': {}, 'urls': {}, 'parents': {}, 'items_by_ids': {}, 'tree_aliases': {}}
+
+            cache_ = cache.get(
+                # Init cache dictionary with predefined entries.
+                'sitetrees', {'sitetrees': {}, 'urls': {}, 'parents': {}, 'items_by_ids': {}, 'tree_aliases': {}})
+
+            setattr(_THREAD_LOCAL, _THREAD_CACHE, cache_)
+
         self.cache = cache_
 
     def save(self):
@@ -305,6 +312,7 @@ class Cache(object):
     def empty(self, **kwargs):
         """Empties cached sitetree data."""
         self.cache = None
+        setattr(_THREAD_LOCAL, _THREAD_CACHE, None)
         cache.delete('sitetrees')
         cache.delete('sitetrees_reset')
 
@@ -410,9 +418,16 @@ class SiteTree(object):
 
     def current_app_is_admin(self):
         """Returns boolean whether current application is Admin contrib."""
-        current_app = (
-            getattr(self._global_context.get('request', None), 'current_app',
-                    self._global_context.current_app))
+        global_context = self._global_context
+
+        current_app = getattr(
+            # Try from request.resolver_match.app_name
+            getattr(global_context.get('request', None), 'resolver_match', None), 'app_name',
+            # Try from global context obj.
+            getattr(global_context, 'current_app', None))
+
+        if current_app is None:  # Try from global context dict.
+            current_app = global_context.get('current_app', '')
 
         return current_app == 'admin'
 
@@ -427,8 +442,6 @@ class SiteTree(object):
         get_cache_entry = cache.get_entry
         set_cache_entry = cache.set_entry
 
-        cache.init()
-
         sitetree_needs_caching = False
         if not self.current_app_is_admin():
             # We do not need i18n for a tree rendered in Admin dropdown.
@@ -638,11 +651,16 @@ class SiteTree(object):
         self.lang_init()
         # Resolve tree_alias from the context.
         tree_alias = self.resolve_var(tree_alias)
+
+        self.cache.init()  # Warm up cache.
+
         # Get tree.
         tree_alias, sitetree_items = self.get_sitetree(tree_alias)
+
         # No items in tree, fail silently.
         if not sitetree_items:
             return False, False
+
         return tree_alias, sitetree_items
 
     def get_current_page_title(self, tree_alias, context):
@@ -856,6 +874,7 @@ class SiteTree(object):
         if start_from.inbreadcrumbs and start_from.hidden == False and self.check_access(start_from,
                                                                                          self._global_context):
             self.cache_breadcrumbs.append(start_from)
+
         if hasattr(start_from, 'parent') and start_from.parent is not None:
             self.breadcrumbs_climber(tree_alias, self.get_item_by_id(tree_alias, start_from.parent.id))
 
@@ -879,7 +898,3 @@ class SiteTree(object):
                 varname = varname
 
         return varname
-
-
-class SiteTreeError(Exception):
-    """Exception class for sitetree application."""
